import { Configuration, App } from '@midwayjs/core';
import * as koa from '@midwayjs/koa';
import * as validate from '@midwayjs/validate';
import * as info from '@midwayjs/info';
import { join } from 'path';
import { DefaultErrorFilter } from './filter/Default.filter';
// import { NotFoundFilter } from './filter/notfound.filter';
import { ReportMiddleware } from './middleware/report.middleware';
import { CustomErrorFilter } from './filter/ServiceError.filter';
import * as busboy from '@midwayjs/busboy';
import * as orm from '@midwayjs/typeorm';
import * as jwt from '@midwayjs/jwt';
import { CheckTokenMiddleware } from './middleware/CheckToken.middleware';
@Configuration({
  imports: [
    koa,
    validate,
    busboy,
    orm,
    jwt,
    {
      component: info,
      enabledEnvironment: ['local'],
    },
  ],
  importConfigs: [join(__dirname, './config')],
})
export class MainConfiguration {
  @App('koa')
  app: koa.Application;

  async onReady() {
    // add middleware
    this.app.useMiddleware([ReportMiddleware, CheckTokenMiddleware]);
    // add filter
    this.app.useFilter([CustomErrorFilter, DefaultErrorFilter]);
    // this.app.useFilter([NotFoundFilter, DefaultErrorFilter]);
  }
}
