import { Controller, Post, Body, Param, Inject, Config } from '@midwayjs/core';
import { LoginService } from '../../service/frame/Login.service';
import { LoginType, LoginVO, UPwdDTO } from '../../frame/Options';
import { JwtService } from '@midwayjs/jwt';
import { LoginRecordService } from '../../service/frame/LoginRecord.service';
import { RF } from '../../response/CustomerResponse';
import { Validate } from '@midwayjs/validate';

@Controller('/login')
export class LoginController {
  @Inject()
  loginService: LoginService;
  @Inject()
  loginRecordService: LoginRecordService;
  @Config('jwt.secret')
  jwtSecret;
  @Inject()
  jwtService: JwtService;
  /**
   * 账密登录
   * @param data 用户名和密码
   * @param type 用户类型
   */
  @Post('/:type')
  async toLogin(@Body() data, @Param('type') type: string) {
    const user = await this.loginService.loginByAccount(data, LoginType[type]);
    if (user) user.role = type;
    let vo = new LoginVO(user);
    vo = JSON.parse(JSON.stringify(vo));
    // user数据写成
    const token = await this.jwtService.sign(vo, this.jwtSecret);
    // 创建/更新登录信息
    await this.loginRecordService.create(token);
    return RF.success(token);
  }

  /**
   * 修改密码
   * @param data 修改密码所需数据
   * @param type 账户类型
   */
  @Validate()
  @Post('/updatePwd/:type')
  async updatePwd(@Body() data: UPwdDTO, @Param('type') type: string) {
    await this.loginService.updatePwd(data, LoginType[type]);
    return RF.success()
  }
  /**
   * 重置密码
   * @param id 用户id
   * @param type 用户类型
   */
  @Post('/resetPwd/:type')
  async resetPwd(@Body('id') id: number, @Param('type') type: string) {
    // 随机密码,不需要写密码字段,函数内会给
    const data = new UPwdDTO();
    data.id = id;
    const password = await this.loginService.updatePwd(data, LoginType[type]);
    return RF.success(password);
  }
}
