import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
} from '@midwayjs/core';
import { ResultService } from '../service/result.service';
import { RF } from '../response/CustomerResponse';
import { Page, Query } from '../decorator/page.decorator';

@Controller('/result')
export class resultController {
  @Inject()
  service: ResultService;

  @Post('/')
  async create(@Body() body) {
    const data = await this.service.create(body);
    return RF.success(data);
  }

  @Get('/')
  async query(@Query() query, @Page() page) {
    const result = await this.service.query(query, page);
    return RF.success(result);
  }

  @Get('/:id')
  async fetch(@Param('id') id: number) {
    const result = await this.service.fetch({ id });
    return RF.success(result);
  }

  @Post('/:id')
  async update(@Param('id') id: number, @Body() body) {
    const result = await this.service.update({ id }, body);
    return RF.success(result);
  }

  @Del('/:id')
  async delete(@Param('id') id: number) {
    await this.service.delete({ id });
    return RF.success();
  }
}
