import { BaseService } from '../../frame/BaseService';
import { Inject, Provide } from '@midwayjs/core';
import { lowerFirst, upperFirst, last, flattenDeep, uniq, get } from 'lodash';
import { ServiceError } from '../../error/CustomerError.error';
import { MenusService } from './menus.service';
import { ErrorCode } from '../../error/Codes';
import { Repository, In } from 'typeorm';
import { InjectEntityModel } from '@midwayjs/typeorm';
import { Menus } from '../../entity/system/menus.entity';
import { Role } from '../../entity/system/role.entity';
@Provide()
export class RoleService extends BaseService {
  @InjectEntityModel(Role)
  model: Repository<Role>;
  @InjectEntityModel(Menus)
  menusModel: Repository<Menus>;
  @Inject()
  menusService: MenusService;

  //是否是超级管理员
  isSuperAdmin() {
    const user = this.ctx.user;
    if (user.role === 'Admin' && user.is_super === '0') return true;
  }

  async getUserMenus(needCode = false) {
    const user = this.ctx.user;
    // 这里需要改下. 平台的超级管理员有这些权限
    if (this.isSuperAdmin()) {
      const menus = await this.menusService.queryMenu({ is_use: 0 });
      return { menus };
    }
    const roleCode = [lowerFirst(user.role), upperFirst(user.role)];
    const q1: any = { code: roleCode, is_use: '0' }
    const role = await this.model.findOne({ where: q1 })
    if (!role) throw new ServiceError(ErrorCode.ROLE_IS_DISABLED);
    const roleMenu = get(role, 'menu', []);
    const menu = roleMenu.map(i => {
      const arr = i.split('.');
      return last(arr);
    });
    if (needCode) return roleMenu;
    const q2: any = { route_name: In(menu) }
    const menuList = await this.menusModel.find({ where: q2 });
    let treeMenu = menuList.filter(f => !f.parent_id);
    treeMenu = this.menusService.treeMenu(menuList, treeMenu);
    return { menus: treeMenu, role_code: roleMenu };
  }

  /**
   * 根据角色id数组,整理菜单
   * @param roleIdList 角色id数组
   */
  async getMenuByRoles(roleIdList) {
    let menus = [];
    // 第一步,整理所有菜单至一维数组
    for (const r of roleIdList) {
      menus.push(...flattenDeep(r));
    }
    menus = uniq(menus);
    const q: any = { id: In(menus), is_use: '0' }
    const allMenu = await this.menusModel
      .find({ where: q, order: { order_num: 'ASC' } })
    let treeMenu = allMenu.filter(f => !f.parent_id);
    treeMenu = this.menusService.treeMenu(allMenu, treeMenu);
    return treeMenu;
  }
}
