import { Application, Context } from '@midwayjs/koa';
import { Opera } from './dbOpera';
import { Repository } from 'typeorm';
/**
 * query默认的查询方式(哪个字段 是 = 还是 IN 还是 LIKE)的设置函数为getQueryColumnsOpera,如果有需要重写即可,返回object
 * {
 *    column: Opera.xxx
 * }
 */
export declare abstract class BaseService {
    app: Application;
    ctx: Context;
    /**service的model,数据库操作 */
    abstract model: Repository<any>;
    /**返回{column:查询方式}.特殊的查询需要写入,不写入默认采用 =  */
    getQueryColumnsOpera(): {};
    /** */
    Opera: typeof Opera;
    /**
     * 默认查询列表
     * @param query @Query直接获取的参数
     * @param param @Query和调用前可组织的参数
     * @param {object} operas 指定查询方式
     * @property {number} param.skip 查询数据起始位置
     * @property {number} param.limit 查询数据的数量
     * @property {object} param.order 使用的排序 {${column}:'DESC'/'ASC'}
     * @property {Array<string>} selects 指定显示的字段
     */
    query(query?: object, meta?: any, operas?: any): Promise<{
        data: any[];
        total: number;
    }>;
    /**
     * 单查询，不止用id还可以根据别的条件,默认全等,可以在调用时,进行查询方式设置
     * @param {object} query 查询条件
     * @param {object} operas 指定查询方式
     */
    fetch(query: object, operas?: {}): Promise<any>;
    /**创建 */
    create(data: object): Promise<any>;
    /**修改，单修改/多修改是统一修改为 */
    update(query: object, data: object): Promise<void>;
    /**删除，单删多删都行 */
    delete(query: object): Promise<import("typeorm").DeleteResult>;
    /**检查有没有指定字段,是从model的映射关系中查询下 */
    private checkModelHaveColumn;
}
