import { Context } from '@midwayjs/koa';
/**
 * 文件上传相关服务
 */
export declare class FileService {
    ctx: Context;
    uploadConfig: any;
    routePrefix: string;
    dbName: string;
    /**临时文件表名 */
    tmpModelName: string;
    /**临时文件表model */
    tmpModel: any;
    /**
     * 删除不在文件使用表登记的文件
     * 1.创建临时表,字段为文件地址;
     * 2.获取config中配置的${表名}.${字段名}.找到所有文件对象,并把uri拿出来存在临时表中
     * 3.获取存放根目录地址,递归检索目录下的文件,并查询下文件在临时表中是否存在:
     *  若存在,则文件保留,跳过处理;
     *  若不存在,则删除文件.文件可能被替换
     * 4.并且,在处理文件过程中,禁用上传功能
     */
    deleteNoUseFile(): Promise<void>;
    /**创建临时文件表 */
    /**
     * 递归找文件
     * @param basePath 基础路径
     * @param list 基础路径下的所有内容
     */
    recursionFindFile(basePath: any): Promise<void>;
    /**
     * 真实路径=>短地址
     * @param realPath 文件真实路径
     * @returns string 短地址
     */
    realPathTurnToShortPath(realPath: string): string;
    /**
     * 删除文件
     * @param path 文件路径
     */
    toUnlink(path: any): void;
    /**
     * 判断路径是否存在
     * @param path 路径
     * @returns boolean: true-存在/false-不存在
     */
    isExists(path: any): boolean;
    /**
     * 判断是否是文件夹
     * @param path 路径
     * @returns boolean: true-是文件夹
     */
    isDir(path: any): boolean;
    /**
     * 判断是否是文件
     * @param path 路径
     * @returns boolean: true-是文件
     */
    isFile(path: any): boolean;
    getFilesPartsPath(): string;
    /**
     * 获取文件短路径
     * @param dirs 文件存储路径
     * @param filename 文件名
     */
    getFileShortPath(dirs: Array<string>, filename: string): string;
    /**文件真实短地址 */
    getFileShortRealPath(): string;
    /**
     * 移动文件
     * @param tempPath 临时上传文件位置
     * @param path 实际文件应处位置
     */
    moveFile(tempPath: string, path: string): void;
    mkdir(dn: string): boolean;
    /**获取文件名后缀 */
    getExt(name: string): string;
    /**获取年月日时分秒, 格式: 年月日时分秒 */
    getNowDateTime(): string;
}
